| Title: | Analysis of Large-Scale Toxico-Genomic Data |
|---|---|
| Description: | Contains a set of functions to perform large-scale analysis of toxicogenomic data, providing a standardized data structure to hold information relevant to annotation, visualization and statistical analysis of toxicogenomic data. |
| Authors: | Sisira Nair [aut], Esther Yoo [aut], Christopher Eeles [aut], Amy Tang [aut], Nehme El-Hachem [aut], Petr Smirnov [aut], Jermiah Joseph [aut], Benjamin Haibe-Kains [aut, cre] |
| Maintainer: | Benjamin Haibe-Kains <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 2.17.0 |
| Built: | 2026-05-30 09:46:28 UTC |
| Source: | https://github.com/bioc/ToxicoGx |
[[
## S4 method for signature 'ToxicoSet,ANY,ANY,ANY' x[i, j, ..., drop = FALSE]## S4 method for signature 'ToxicoSet,ANY,ANY,ANY' x[i, j, ..., drop = FALSE]
x |
tSet |
i |
Cell lines to keep in tSet |
j |
Drugs to keep in tSet |
... |
further arguments |
drop |
A boolean flag of whether to drop single dimensions or not |
Returns the subsetted tSet
tSet <- TGGATESsmall[sampleNames(TGGATESsmall), treatmentNames(TGGATESsmall)[seq_len(3)]]tSet <- TGGATESsmall[sampleNames(TGGATESsmall), treatmentNames(TGGATESsmall)[seq_len(3)]]
The function fetches a table of all ToxicoSets available for download from the ToxicoGx server. The table includes the names of the ToxicoSet, the types of data available in the object, and the date of last update.
availableTSets(canonical = TRUE)availableTSets(canonical = TRUE)
canonical |
|
Much more information on the processing of the data and data provenance can be found at: www.orcestra.ca
A data.frame with details about the available ToxicoSet objects
if (interactive()){ availableTSets() }if (interactive()){ availableTSets() }
This function checks the structure of a ToxicoSet, ensuring that the correct annotations are in place and all the required slots are filled so that matching of cells and drugs can be properly done across different types of data and with other studies.
checkTSetStructure(tSet, plotDist = FALSE, result.dir = ".")checkTSetStructure(tSet, plotDist = FALSE, result.dir = ".")
tSet |
A |
plotDist |
Should the function also plot the distribution of molecular data? |
result.dir |
The path to the directory for saving the plots as a string, defaults to |
Prints out messages whenever describing the errors found in the structure of the pset object passed in.
checkTSetStructure(TGGATESsmall)checkTSetStructure(TGGATESsmall)
Returns the AUC (Area Under the drug response Curve) given concentration and viability as input, normalized by the concentration range of the experiment. The area returned is the response (1-Viablility) area, i.e. area under the curve when the response curve is plotted on a log10 concentration scale, with high AUC implying high sensitivity to the drug. The function can calculate both the area under a fitted Hill Curve to the data, and a trapz numeric integral of the actual data provided. Alternatively, the parameters of a Hill Slope returned by logLogisticRegression can be passed in if they already known.
computeAUC( concentration, viability, Hill_fit, conc_as_log = FALSE, viability_as_pct = TRUE, trunc = TRUE, area.type = c("Fitted", "Actual"), verbose = TRUE )computeAUC( concentration, viability, Hill_fit, conc_as_log = FALSE, viability_as_pct = TRUE, trunc = TRUE, area.type = c("Fitted", "Actual"), verbose = TRUE )
concentration |
|
viability |
|
Hill_fit |
|
conc_as_log |
|
viability_as_pct |
|
trunc |
|
area.type |
Should the area be computed using the actual data ("Actual"), or a fitted curve ("Fitted") |
verbose |
|
Numeric AUC value
dose <- c("0.0025","0.008","0.025","0.08","0.25","0.8","2.53","8") viability <- c("108.67","111","102.16","100.27","90","87","74","57") computeAUC(dose, viability)dose <- c("0.0025","0.008","0.025","0.08","0.25","0.8","2.53","8") viability <- c("108.67","111","102.16","100.27","90","87","74","57") computeAUC(dose, viability)
Returns the ICn for any given nth percentile when given concentration and viability as input, normalized by the concentration range of the experiment. A Hill Slope is first fit to the data, and the ICn is inferred from the fitted curve. Alternatively, the parameters of a Hill Slope returned by logLogisticRegression can be passed in if they already known.
computeIC50( concentration, viability, Hill_fit, conc_as_log = FALSE, viability_as_pct = TRUE, verbose = TRUE, trunc = TRUE ) computeICn( concentration, viability, Hill_fit, n, conc_as_log = FALSE, viability_as_pct = TRUE, verbose = TRUE, trunc = TRUE )computeIC50( concentration, viability, Hill_fit, conc_as_log = FALSE, viability_as_pct = TRUE, verbose = TRUE, trunc = TRUE ) computeICn( concentration, viability, Hill_fit, n, conc_as_log = FALSE, viability_as_pct = TRUE, verbose = TRUE, trunc = TRUE )
concentration |
|
viability |
|
Hill_fit |
|
conc_as_log |
|
viability_as_pct |
|
verbose |
|
trunc |
|
n |
|
a numeric value for the concentration of the nth precentile viability reduction
computeIC50(): Returns the IC50 of a Drug Dose response curve
dose <- c("0.0025","0.008","0.025","0.08","0.25","0.8","2.53","8") viability <- c("108.67","111","102.16","100.27","90","87","74","57") computeIC50(dose, viability) computeICn(dose, viability, n=10)dose <- c("0.0025","0.008","0.025","0.08","0.25","0.8","2.53","8") viability <- c("108.67","111","102.16","100.27","90","87","74","57") computeIC50(dose, viability) computeICn(dose, viability, n=10)
Generic method for performing differential expression analysis on an S4 object using the limma package
computeLimmaDiffExpr(object, ...)computeLimmaDiffExpr(object, ...)
object |
|
... |
Allow new parameters to be added to this generic. |
To be defined by the method implementation.
WARNING: This function can take a very long time to compute!
## S4 method for signature 'ToxicoSet' computeLimmaDiffExpr(object, buildTable = TRUE)## S4 method for signature 'ToxicoSet' computeLimmaDiffExpr(object, buildTable = TRUE)
object |
A |
buildTable |
|
A data.table containing the results the limma differential
expression analysis comparing control vs each dose level for each compound
within each duration.
if (interactive()) { data(TGGATESsmall) analysis <- computeLimmaDiffExpr(TGGATESsmall) }if (interactive()) { data(TGGATESsmall) analysis <- computeLimmaDiffExpr(TGGATESsmall) }
Get the dimensions of a ToxicoSet
## S4 method for signature 'ToxicoSet' dim(x)## S4 method for signature 'ToxicoSet' dim(x)
x |
ToxicoSet |
A named vector with the number of Cells and Drugs in the ToxicoSet
data(TGGATESsmall) dim(TGGATESsmall)data(TGGATESsmall) dim(TGGATESsmall)
This function allows you to download a ToxicoSet object for use with this
package. The ToxicoSets have been extensively curated and organised within
a ToxicoSet class, enabling use with all the analysis tools provided in
ToxicoGx.
downloadTSet( name, saveDir = tempdir(), tSetFileName = NULL, verbose = TRUE, timeout = 600 )downloadTSet( name, saveDir = tempdir(), tSetFileName = NULL, verbose = TRUE, timeout = 600 )
name |
|
saveDir |
|
tSetFileName |
|
verbose |
|
timeout |
|
A tSet object with the dataset, downloaded from our server
if (interactive()) { drugMatrix_rat <- downloadTSet("DrugMatrix Rat") }if (interactive()) { drugMatrix_rat <- downloadTSet("DrugMatrix Rat") }
This function generates a plot visualizing the relationship between gene expression, time and dose level for the selected tSet. The plot is generated with ggplot2 and can be customized using ggplot plot + function() syntax.
drugGeneResponseCurve( tSet, duration = NULL, cell_lines = NULL, mDataTypes = NULL, features = NULL, dose = NULL, drug = NULL, summarize_replicates = TRUE, line_width = 1, point_size = 2.5, ggplot_args = NULL, verbose = TRUE )drugGeneResponseCurve( tSet, duration = NULL, cell_lines = NULL, mDataTypes = NULL, features = NULL, dose = NULL, drug = NULL, summarize_replicates = TRUE, line_width = 1, point_size = 2.5, ggplot_args = NULL, verbose = TRUE )
tSet |
|
duration |
|
cell_lines |
|
mDataTypes |
|
features |
|
dose |
|
drug |
|
summarize_replicates |
|
line_width |
|
point_size |
|
ggplot_args |
|
verbose |
|
Plot of the viabilities for each drug vs time of exposure
if (interactive()) { drugGeneResponseCurve(TGGATESsmall, dose = c("Control", "Low", "Middle"), mDataTypes="rna", drug = treatmentNames(TGGATESsmall)[1], duration = c("2", "8", "24"), features = "ENSG00000002726_at") }if (interactive()) { drugGeneResponseCurve(TGGATESsmall, dose = c("Control", "Low", "Middle"), mDataTypes="rna", drug = treatmentNames(TGGATESsmall)[1], duration = c("2", "8", "24"), features = "ENSG00000002726_at") }
Creates a signature representing gene expression (or other molecular profile) change induced by administrating a drug, for use in drug effect analysis.
drugPerturbationSig( tSet, mDataType, drugs = NULL, cell_lines = NULL, features = NULL, duration = NULL, dose = NULL, nthread = 1, returnValues = c("estimate", "tstat", "pvalue", "fdr"), verbose = FALSE )drugPerturbationSig( tSet, mDataType, drugs = NULL, cell_lines = NULL, features = NULL, duration = NULL, dose = NULL, nthread = 1, returnValues = c("estimate", "tstat", "pvalue", "fdr"), verbose = FALSE )
tSet |
|
mDataType |
|
drugs |
|
cell_lines |
|
features |
|
duration |
|
dose |
|
nthread |
|
returnValues |
|
verbose |
|
Given a Toxicoset of the perturbation experiment type, and a character vector of drugs, the function will compute a signature for the effect of drug concentration on the molecular profile of a cell. The algorithm uses a regression model which corrects for experimental batch effects, cell specific differences, and duration of experiment to isolate the effect of the concentration of the drug applied. The function returns the estimated coefficient for concentration, the t-stat, the p-value and the false discovery rate associated with that coefficient, in a 3 dimensional array, with genes in the first direction, drugs in the second, and the selected return values in the third.
ToxicoSig An object composed of a 3D array with genes in the
first dimension, drugs in the second, and return values in the third.
if (interactive()) { data(TGGATESsmall) drug.perturbation <- drugPerturbationSig(TGGATESsmall, mDataType="rna", features = head(fNames(TGGATESsmall, "rna")), nthread=1) }if (interactive()) { data(TGGATESsmall) drug.perturbation <- drugPerturbationSig(TGGATESsmall, mDataType="rna", features = head(fNames(TGGATESsmall, "rna")), nthread=1) }
This function generates a plot visualizing the relationship between gene expression, time and dose level for the selected tSet. The plot is generated with ggplot2 and can be customized using ggplot plot + function() syntax.
drugTimeResponseCurve( tSet, duration = NULL, cell_lines = NULL, dose = NULL, drugs = NULL, summarize_replicates = TRUE, line_width = 1, point_size = 2.5, verbose = TRUE, ggplot_args = NULL )drugTimeResponseCurve( tSet, duration = NULL, cell_lines = NULL, dose = NULL, drugs = NULL, summarize_replicates = TRUE, line_width = 1, point_size = 2.5, verbose = TRUE, ggplot_args = NULL )
tSet |
|
duration |
|
cell_lines |
|
dose |
|
drugs |
|
summarize_replicates |
|
line_width |
|
point_size |
|
verbose |
|
ggplot_args |
|
Plot of the viabilities for each drugs vs time of exposure
library(ggplot2) # Default settings plot <- drugTimeResponseCurve(TGGATESsmall, cell_lines = "Hepatocyte", dose = c("Control", "Low", "Middle"), drugs = treatmentNames(TGGATESsmall)[6], duration = c("2", "8", "24")) # Customize title, x/y labels, x/y limits, colour palette and define # custom ticks for x axis using the function argument ggplot2_args customizations <- list(labs(title= 'My Custom Title', ylab = 'The y-axis'), xlim(c(2, 24)), ylim(c(99,105)), scale_color_brewer(palette="Set1"), scale_x_continuous(breaks=c(2, 8, 24), labels = c("Two", "Eight", "Twenty-Four")) ) if(interactive()) { drugTimeResponseCurve(TGGATESsmall, cell_lines = "Hepatocyte", dose = c("Control", "Low", "Middle"), drugs = treatmentNames(TGGATESsmall)[6], duration = c("2", "8", "24"), ggplot_args = customizations) } # Customize the plot using standard ggplot2 syntax if(interactive()) { plot + labs(title= 'My Custom Title', ylab = 'The y-axis') + xlim(c(2, 24)) + ylim(c(99,105)) + scale_color_brewer(palette="Set1") }library(ggplot2) # Default settings plot <- drugTimeResponseCurve(TGGATESsmall, cell_lines = "Hepatocyte", dose = c("Control", "Low", "Middle"), drugs = treatmentNames(TGGATESsmall)[6], duration = c("2", "8", "24")) # Customize title, x/y labels, x/y limits, colour palette and define # custom ticks for x axis using the function argument ggplot2_args customizations <- list(labs(title= 'My Custom Title', ylab = 'The y-axis'), xlim(c(2, 24)), ylim(c(99,105)), scale_color_brewer(palette="Set1"), scale_x_continuous(breaks=c(2, 8, 24), labels = c("Two", "Eight", "Twenty-Four")) ) if(interactive()) { drugTimeResponseCurve(TGGATESsmall, cell_lines = "Hepatocyte", dose = c("Control", "Low", "Middle"), drugs = treatmentNames(TGGATESsmall)[6], duration = c("2", "8", "24"), ggplot_args = customizations) } # Customize the plot using standard ggplot2 syntax if(interactive()) { plot + labs(title= 'My Custom Title', ylab = 'The y-axis') + xlim(c(2, 24)) + ylim(c(99,105)) + scale_color_brewer(palette="Set1") }
A dataset cotaining the gene names associated with the HCC geneset signature
data(HCC_sig)data(HCC_sig)
character
By default, logLogisticRegression uses an L-BFGS algorithm to generate the fit. However, if this fails to converge to solution, logLogisticRegression samples lattice points throughout the parameter space. It then uses the lattice point with minimal least-squares residual as an initial guess for the optimal parameters, passes this guess to drm, and re-attempts the optimization. If this still fails, logLogisticRegression uses the PatternSearch algorithm to fit a log-logistic curve to the data.
logLogisticRegression( conc, viability, density = c(2, 10, 2), step = 0.5/density, precision = 0.05, lower_bounds = c(0, 0, -6), upper_bounds = c(4, 1, 6), scale = 0.07, family = c("normal", "Cauchy"), median_n = 1, conc_as_log = FALSE, viability_as_pct = TRUE, trunc = TRUE, verbose = FALSE )logLogisticRegression( conc, viability, density = c(2, 10, 2), step = 0.5/density, precision = 0.05, lower_bounds = c(0, 0, -6), upper_bounds = c(4, 1, 6), scale = 0.07, family = c("normal", "Cauchy"), median_n = 1, conc_as_log = FALSE, viability_as_pct = TRUE, trunc = TRUE, verbose = FALSE )
conc |
vector is a vector of drug concentrations. |
viability |
vector is a vector whose entries are the viability values observed in the presence of the drug concentrations whose logarithms are in the corresponding entries of the log_conc, where viability 0 indicates that all cells died, and viability 1 indicates that the drug had no effect on the cells. |
density |
vector is a vector of length 3 whose components are the numbers of lattice points per unit length along the HS-, E_inf-, and base-10 logarithm of the EC50-dimensions of the parameter space, respectively. |
step |
vector is a vector of length 3 whose entries are the initial step sizes in the HS, E_inf, and base-10 logarithm of the EC50 dimensions, respectively, for the PatternSearch algorithm. |
precision |
is a positive real number such that when the ratio of current step size to initial step size falls below it, the PatternSearch algorithm terminates. A smaller value will cause LogisticPatternSearch to take longer to complete optimization, but will produce a more accurate estimate for the fitted parameters. |
lower_bounds |
vector is a vector of length 3 whose entries are the lower bounds on the HS, E_inf, and base-10 logarithm of the EC50 parameters, respectively. |
upper_bounds |
vector is a vector of length 3 whose entries are the upper bounds on the HS, E_inf, and base-10 logarithm of the EC50 parameters, respectively. |
scale |
is a positive real number specifying the shape parameter of the Cauchy distribution. |
family |
character, if "cauchy", uses MLE under an assumption of Cauchy-distributed errors instead of sum-of-squared-residuals as the objective function for assessing goodness-of-fit of dose-response curves to the data. Otherwise, if "normal", uses MLE with a gaussian assumption of errors |
median_n |
If the viability points being fit were medians of measurements, they are expected to follow a median of |
conc_as_log |
logical, if true, assumes that log10-concentration data has been given rather than concentration data, and that log10(EC50) should be returned instead of EC50. |
viability_as_pct |
logical, if false, assumes that viability is given as a decimal rather than a percentage, and that E_inf should be returned as a decimal rather than a percentage. |
trunc |
logical, if true, causes viability data to be truncated to lie between 0 and 1 before curve-fitting is performed. |
verbose |
logical, if true, causes warnings thrown by the function to be printed. |
A vector containing estimates for HS, E_inf, and EC50
dose <- c("0.0025","0.008","0.025","0.08","0.25","0.8","2.53","8") viability <- c("108.67","111","102.16","100.27","90","87","74","57") computeAUC(dose, viability)dose <- c("0.0025","0.008","0.025","0.08","0.25","0.8","2.53","8") viability <- c("108.67","111","102.16","100.27","90","87","74","57") computeAUC(dose, viability)
Show a ToxicoSet
## S4 method for signature 'ToxicoSet' show(object)## S4 method for signature 'ToxicoSet' show(object)
object |
A |
Prints the ToxicoSet object to the output stream, and returns invisible NULL.
TGGATESsmallTGGATESsmall
Show ToxicoGx Signatures
## S4 method for signature 'ToxicoSig' show(object)## S4 method for signature 'ToxicoSig' show(object)
object |
|
Prints the ToxicoGx Signatures object to the output stream, and returns invisible NULL.
data(TGGATESsmall) drug.perturbation <- drugPerturbationSig(TGGATESsmall, mDataType="rna", nthread = 1, duration = "2", drugs = head(treatmentNames(TGGATESsmall)), features = fNames(TGGATESsmall, "rna")[seq_len(2)]) drug.perturbationdata(TGGATESsmall) drug.perturbation <- drugPerturbationSig(TGGATESsmall, mDataType="rna", nthread = 1, duration = "2", drugs = head(treatmentNames(TGGATESsmall)), features = fNames(TGGATESsmall, "rna")[seq_len(2)]) drug.perturbation
This funtion prints out the information about the call used to compute the drug signatures, and the session info for the session in which the computation was done. Useful for determining the exact conditions used to generate signatures.
showSigAnnot(Sigs)showSigAnnot(Sigs)
Sigs |
An object of the |
Prints the ToxicoGx Signatures annotations to the output stream, and returns invisible NULL.
data(TGGATESsmall) drug.perturbation <- drugPerturbationSig(TGGATESsmall, mDataType="rna", nthread=1, duration = "2", drugs = head(treatmentNames(TGGATESsmall)), features = fNames(TGGATESsmall, "rna")[seq_len(2)]) showSigAnnot(drug.perturbation)data(TGGATESsmall) drug.perturbation <- drugPerturbationSig(TGGATESsmall, mDataType="rna", nthread=1, duration = "2", drugs = head(treatmentNames(TGGATESsmall)), features = fNames(TGGATESsmall, "rna")[seq_len(2)]) showSigAnnot(drug.perturbation)
This is the prefered method of subsetting a ToxicoSet. This function allows abstraction of the data to the level of biologically relevant objects: drugs and cells. The function will automatically go through all of the combined data in the ToxicoSet and ensure only the requested radiations and cell lines are found in any of the slots. This allows quickly picking out all the experiments for a radiation or cell of interest, as well removes the need to keep track of all the metadata conventions between different datasets.
subsetTo( object, cell_lines = NULL, drugs = NULL, molecular.data.cells = NULL, duration = NULL, features = NULL, ... )subsetTo( object, cell_lines = NULL, drugs = NULL, molecular.data.cells = NULL, duration = NULL, features = NULL, ... )
object |
A |
cell_lines |
A list or vector of cell names as used in the dataset to which the object will be subsetted. If left blank, then all cells will be left in the dataset. |
drugs |
A list or vector of drug names as used in the dataset to which the object will be subsetted. If left blank, then all drugs will be left in the dataset. |
molecular.data.cells |
A list or vector of cell names to keep in the molecular data |
duration |
A |
features |
A list or vector of feature names as used in the dataset from which the object will be subsetted. If left blank that all features will be left in. |
... |
Other arguments passed to other functions within the package |
A ToxicoSet with only the selected drugs and cells
TGGATESDrugNames <- treatmentNames(TGGATESsmall) TGGATESCells <- sampleNames(TGGATESsmall) tSet <- subsetTo(TGGATESsmall,drugs = TGGATESDrugNames[1], cells = TGGATESCells[1], duration = "2")TGGATESDrugNames <- treatmentNames(TGGATESsmall) TGGATESCells <- sampleNames(TGGATESsmall) tSet <- subsetTo(TGGATESsmall,drugs = TGGATESDrugNames[1], cells = TGGATESCells[1], duration = "2")
Given a ToxicoSet with molecular data, this function will summarize the data into one profile per experimental condition (duration, dose level) using the chosen summary.stat and return a SummarizedExperiment object, with one Assay corresponding to a requested drug.
summarizeMolecularProfiles( tSet, mDataType, cell_lines = NULL, drugs = NULL, features = NULL, duration = NULL, dose = c("Control", "Low", "Middle", "High"), summary.stat = c("mean", "median", "first", "last"), fill.missing = TRUE, summarize = TRUE, verbose = TRUE )summarizeMolecularProfiles( tSet, mDataType, cell_lines = NULL, drugs = NULL, features = NULL, duration = NULL, dose = c("Control", "Low", "Middle", "High"), summary.stat = c("mean", "median", "first", "last"), fill.missing = TRUE, summarize = TRUE, verbose = TRUE )
tSet |
|
mDataType |
|
cell_lines |
|
drugs |
|
features |
|
duration |
|
dose |
|
summary.stat |
|
fill.missing |
|
summarize |
A flag which when set to FALSE (defaults to TRUE) disables summarizing and returns the data unchanged as a ExpressionSet |
verbose |
|
SummarizedExperiment A SummarizedExperiment object with the molecular data summarized
per cell line.
data(TGGATESsmall) summMP <- ToxicoGx::summarizeMolecularProfiles( tSet = TGGATESsmall, mDataType = "rna", cell_lines=sampleNames(TGGATESsmall), drugs = head(treatmentNames(TGGATESsmall)), features = fNames(TGGATESsmall,"rna")[seq_len(100)], duration = "8", dose = c("Control", "High"), summary.stat = "median", fill.missing = TRUE, verbose=TRUE ) #subset into expression matrix for a requested drug assays <- SummarizedExperiment::assays(summMP)[[treatmentNames(TGGATESsmall)[1]]] #summarization of phenoData for requested experiments phenoData <- SummarizedExperiment::colData(summMP) #summarization of phenoData for requested experiments featureData <- SummarizedExperiment::rowData(summMP) #featureData for requested experimentsdata(TGGATESsmall) summMP <- ToxicoGx::summarizeMolecularProfiles( tSet = TGGATESsmall, mDataType = "rna", cell_lines=sampleNames(TGGATESsmall), drugs = head(treatmentNames(TGGATESsmall)), features = fNames(TGGATESsmall,"rna")[seq_len(100)], duration = "8", dose = c("Control", "High"), summary.stat = "median", fill.missing = TRUE, verbose=TRUE ) #subset into expression matrix for a requested drug assays <- SummarizedExperiment::assays(summMP)[[treatmentNames(TGGATESsmall)[1]]] #summarization of phenoData for requested experiments phenoData <- SummarizedExperiment::colData(summMP) #summarization of phenoData for requested experiments featureData <- SummarizedExperiment::rowData(summMP) #featureData for requested experiments
This function creates a table with drug as rows and cell lines as columns, summarising the drug senstitivity data of a ToxicoSet into drug-cell line pairs for a specified experiment duration.
summarizeSensitivityProfiles( tSet, duration = NULL, cell_lines = NULL, drugs = NULL, sensitivity.measure = "auc_recomputed", summary.stat = c("mean", "median", "first", "last", "max", "min"), fill.missing = TRUE, verbose = TRUE )summarizeSensitivityProfiles( tSet, duration = NULL, cell_lines = NULL, drugs = NULL, sensitivity.measure = "auc_recomputed", summary.stat = c("mean", "median", "first", "last", "max", "min"), fill.missing = TRUE, verbose = TRUE )
tSet |
|
duration |
|
cell_lines |
|
drugs |
|
sensitivity.measure |
|
summary.stat |
|
fill.missing |
|
verbose |
Should the function print progress messages? |
matrix A matrix with drugs going down the rows, cell lines across
the columns, with the selected sensitivity statistic for each pair.
data(TGGATESsmall) TGGATESauc <- summarizeSensitivityProfiles(TGGATESsmall, sensitivity.measure='auc_recomputed')data(TGGATESsmall) TGGATESauc <- summarizeSensitivityProfiles(TGGATESsmall, sensitivity.measure='auc_recomputed')
Documentation for this dataset will be added at a later date. For now I just need this package to pass the CRAN checks! This dataset powers the example usage in the roxygen2 documentation for ToxicoGx.
data(TGGATESsmall)data(TGGATESsmall)
ToxicoSet object
Lamb et al. The Connectivity Map: using gene-expression signatures to connect small molecules, genes, and disease. Science, 2006.
A constructor that simplifies the process of creating ToxicoSets, as well as creates empty objects for data not provided to the constructor. Only objects returned by this constructor are expected to work with the ToxicoSet methods. For a much more detailed instruction on creating ToxicoSets, please see the "CreatingToxicoSet" vignette.
ToxicoSet( name, molecularProfiles = list(), sample = data.frame(), treatment = data.frame(), sensitivityInfo = data.frame(), sensitivityRaw = array(dim = c(0, 0, 0)), sensitivityProfiles = matrix(), sensitivityN = matrix(nrow = 0, ncol = 0), perturbationN = array(NA, dim = c(0, 0, 0)), curationTreatment = data.frame(), curationSample = data.frame(), curationTissue = data.frame(), datasetType = c("sensitivity", "perturbation", "both"), verify = TRUE )ToxicoSet( name, molecularProfiles = list(), sample = data.frame(), treatment = data.frame(), sensitivityInfo = data.frame(), sensitivityRaw = array(dim = c(0, 0, 0)), sensitivityProfiles = matrix(), sensitivityN = matrix(nrow = 0, ncol = 0), perturbationN = array(NA, dim = c(0, 0, 0)), curationTreatment = data.frame(), curationSample = data.frame(), curationTissue = data.frame(), datasetType = c("sensitivity", "perturbation", "both"), verify = TRUE )
name |
A |
molecularProfiles |
A |
sample |
A |
treatment |
A |
sensitivityInfo |
A |
sensitivityRaw |
A 3 Dimensional |
sensitivityProfiles |
|
sensitivityN, perturbationN
|
A |
curationSample, curationTissue, curationTreatment
|
A |
datasetType |
A |
verify |
|
An object of class ToxicoSet
CoreSet
Documentation for the various setters and getters which allow manipulation
of data in the slots of a CoreSet object.
drugInfo(...) drugInfo(...) <- value drugNames(...) drugNames(...) <- value ## S4 method for signature 'ToxicoSet' annotation(object) ## S4 replacement method for signature 'ToxicoSet,list' annotation(object) <- value ## S4 method for signature 'ToxicoSet' dateCreated(object) ## S4 replacement method for signature 'ToxicoSet,character' dateCreated(object) <- value ## S4 method for signature 'ToxicoSet' name(object) ## S4 replacement method for signature 'ToxicoSet' name(object) <- value ## S4 method for signature 'ToxicoSet' sampleInfo(object) ## S4 replacement method for signature 'ToxicoSet,data.frame' sampleInfo(object) <- value ## S4 method for signature 'ToxicoSet' sampleNames(object) ## S4 replacement method for signature 'ToxicoSet,character' sampleNames(object) <- value ## S4 method for signature 'ToxicoSet' curation(object) ## S4 replacement method for signature 'ToxicoSet,list' curation(object) <- value ## S4 method for signature 'ToxicoSet' datasetType(object) ## S4 replacement method for signature 'ToxicoSet,character' datasetType(object) <- value ## S4 method for signature 'ToxicoSet' molecularProfiles(object, mDataType, assay) ## S4 replacement method for signature 'ToxicoSet,character,character,matrix' molecularProfiles(object, mDataType, assay) <- value ## S4 method for signature 'ToxicoSet' featureInfo(object, mDataType) ## S4 replacement method for signature 'ToxicoSet,character,data.frame' featureInfo(object, mDataType) <- value ## S4 method for signature 'ToxicoSet,character' phenoInfo(object, mDataType) ## S4 replacement method for signature 'ToxicoSet,character,data.frame' phenoInfo(object, mDataType) <- value ## S4 method for signature 'ToxicoSet,character' fNames(object, mDataType) ## S4 replacement method for signature 'ToxicoSet,character,character' fNames(object, mDataType) <- value ## S4 method for signature 'ToxicoSet' mDataNames(object) ## S4 replacement method for signature 'ToxicoSet' mDataNames(object) <- value ## S4 method for signature 'ToxicoSet' molecularProfilesSlot(object) ## S4 replacement method for signature 'ToxicoSet,list_OR_MAE' molecularProfilesSlot(object) <- value ## S4 method for signature 'ToxicoSet' sensitivityInfo(object, dimension, ...) ## S4 replacement method for signature 'ToxicoSet,data.frame' sensitivityInfo(object, dimension, ...) <- value ## S4 method for signature 'ToxicoSet' sensitivityMeasures(object) ## S4 replacement method for signature 'ToxicoSet,character' sensitivityMeasures(object) <- value ## S4 method for signature 'ToxicoSet' sensitivityProfiles(object) ## S4 replacement method for signature 'ToxicoSet,data.frame' sensitivityProfiles(object) <- value ## S4 method for signature 'ToxicoSet' sensitivityRaw(object) ## S4 replacement method for signature 'ToxicoSet,array' sensitivityRaw(object) <- value ## S4 method for signature 'ToxicoSet' treatmentResponse(object) ## S4 replacement method for signature 'ToxicoSet,list_OR_LongTable' treatmentResponse(object) <- value ## S4 method for signature 'ToxicoSet' sensNumber(object) ## S4 replacement method for signature 'ToxicoSet,matrix' sensNumber(object) <- value ## S4 method for signature 'ToxicoSet' pertNumber(object) ## S4 replacement method for signature 'ToxicoSet,array' pertNumber(object) <- valuedrugInfo(...) drugInfo(...) <- value drugNames(...) drugNames(...) <- value ## S4 method for signature 'ToxicoSet' annotation(object) ## S4 replacement method for signature 'ToxicoSet,list' annotation(object) <- value ## S4 method for signature 'ToxicoSet' dateCreated(object) ## S4 replacement method for signature 'ToxicoSet,character' dateCreated(object) <- value ## S4 method for signature 'ToxicoSet' name(object) ## S4 replacement method for signature 'ToxicoSet' name(object) <- value ## S4 method for signature 'ToxicoSet' sampleInfo(object) ## S4 replacement method for signature 'ToxicoSet,data.frame' sampleInfo(object) <- value ## S4 method for signature 'ToxicoSet' sampleNames(object) ## S4 replacement method for signature 'ToxicoSet,character' sampleNames(object) <- value ## S4 method for signature 'ToxicoSet' curation(object) ## S4 replacement method for signature 'ToxicoSet,list' curation(object) <- value ## S4 method for signature 'ToxicoSet' datasetType(object) ## S4 replacement method for signature 'ToxicoSet,character' datasetType(object) <- value ## S4 method for signature 'ToxicoSet' molecularProfiles(object, mDataType, assay) ## S4 replacement method for signature 'ToxicoSet,character,character,matrix' molecularProfiles(object, mDataType, assay) <- value ## S4 method for signature 'ToxicoSet' featureInfo(object, mDataType) ## S4 replacement method for signature 'ToxicoSet,character,data.frame' featureInfo(object, mDataType) <- value ## S4 method for signature 'ToxicoSet,character' phenoInfo(object, mDataType) ## S4 replacement method for signature 'ToxicoSet,character,data.frame' phenoInfo(object, mDataType) <- value ## S4 method for signature 'ToxicoSet,character' fNames(object, mDataType) ## S4 replacement method for signature 'ToxicoSet,character,character' fNames(object, mDataType) <- value ## S4 method for signature 'ToxicoSet' mDataNames(object) ## S4 replacement method for signature 'ToxicoSet' mDataNames(object) <- value ## S4 method for signature 'ToxicoSet' molecularProfilesSlot(object) ## S4 replacement method for signature 'ToxicoSet,list_OR_MAE' molecularProfilesSlot(object) <- value ## S4 method for signature 'ToxicoSet' sensitivityInfo(object, dimension, ...) ## S4 replacement method for signature 'ToxicoSet,data.frame' sensitivityInfo(object, dimension, ...) <- value ## S4 method for signature 'ToxicoSet' sensitivityMeasures(object) ## S4 replacement method for signature 'ToxicoSet,character' sensitivityMeasures(object) <- value ## S4 method for signature 'ToxicoSet' sensitivityProfiles(object) ## S4 replacement method for signature 'ToxicoSet,data.frame' sensitivityProfiles(object) <- value ## S4 method for signature 'ToxicoSet' sensitivityRaw(object) ## S4 replacement method for signature 'ToxicoSet,array' sensitivityRaw(object) <- value ## S4 method for signature 'ToxicoSet' treatmentResponse(object) ## S4 replacement method for signature 'ToxicoSet,list_OR_LongTable' treatmentResponse(object) <- value ## S4 method for signature 'ToxicoSet' sensNumber(object) ## S4 replacement method for signature 'ToxicoSet,matrix' sensNumber(object) <- value ## S4 method for signature 'ToxicoSet' pertNumber(object) ## S4 replacement method for signature 'ToxicoSet,array' pertNumber(object) <- value
... |
See details. |
value |
See details. |
object |
A |
mDataType |
|
assay |
|
dimension |
See details. |
treatmentInfo: data.frame Metadata for all treatments in a ToxicoSet
object. Arguments:
object: ToxicoSet An object to retrieve treatment metadata from.
treatmentInfo<-: ToxicoSet object with updated treatment metadata.
object. Arguments:
object: ToxicoSet An object to set treatment metadata for.
value: data.frame A new table of treatment metadata for object.
treatmentNames: character Names for all treatments in a ToxicoSet
object. Arguments:
object: ToxicoSet An object to retrieve treatment names from.
treatmentNames<-: ToxicoSet Object with updates treatment names.
object. Arguments:
object: ToxicoSet An object to set treatment names from.
value: character A character vector of updated treatment names.
annotation: A list of ToxicoSet annotations with items: 'name',
the name of the object; 'dateCreated', date the object was created; 'sessionInfo',
the sessionInfo() when the object was created; 'call', the R constructor call;
and 'version', the object version.
annotation<-: Setter method for the annotation slot. Arguments:
value: a list of annotations to update the ToxicoSet with.
dateCreated: character(1) The date the ToxicoSet object was
created, as returned by the date() function.
dateCreated<-: Update the 'dateCreated' item in the annotation slot of
a ToxicoSet object. Arguments:
value: A character(1) vector, as returned by the date() function.
name: character(1) The name of the ToxicoSet, retreived from
the @annotation slot.
name<-: Update the @annotation$name value in a ToxicoSet object.
value: character(1) The name of the ToxicoSet object.
cellInfo: data.frame Metadata for all sample in a ToxicoSet object.
sampleInfo<-: assign updated sample annotations to the ToxicoSet
object.
Arguments:
value: a data.frame object.
sampleNames: character Retrieve the rownames of the data.frame in
the sample slot from a ToxicoSet object.
sampleNames<-: assign new rownames to the sampleInfo data.frame for
a ToxicoSet object.
Arguments:
value: character vector of rownames for the sampleInfo(object) data.frame.
curation: A list of curated mappings between identifiers in the
ToxicoSet object and the original data publication. Contains three data.frames, 'cell' with
cell-line ids and 'tissue' with tissue ids and 'drug' with drug ids.
curation<-: Update the curation slot of a ToxicoSet object. Arugments:
value: A list of data.frames, one for each type of curated
identifier. For a ToxicoSet object the slot should
contain tissue, cell-line and drug id data.frames.
datasetType: character(1) The type treatment response in the
sensitivity slot. Valid values are 'sensitivity', 'perturbation' or 'both'.
datasetType<-: Update the datasetType slot of a ToxicoSet object. Arguments:
value: A character(1) vector with one of 'sensitivity', 'perturbation'
or 'both'
molecularProfiles: matrix() Retrieve an assay in a
SummarizedExperiment from the molecularProfiles slot of a ToxicoSet
object with the specified mDataType. Valid mDataType arguments can be
found with mDataNames(object). Exclude mDataType and assay to
access the entire slot. Arguments:
assay: Optional character(1) vector specifying an assay in the
SummarizedExperiment of the molecularProfiles slot of the
ToxicoSet object for the specified mDataType. If excluded,
defaults to modifying the first assay in the SummarizedExperiment for
the given mDataType.
molecularProfiles<-: Update an assay in a SummarizedExperiment from
the molecularProfiles slot of a ToxicoSet object with the specified
mDataType. Valid mDataType arguments can be found with
mDataNames(object). Omit mDataType and assay to update the slot.
assay: Optional character(1) vector specifying an assay in the
SummarizedExperiment of the molecularProfiles slot of the
ToxicoSet object for the specified mDataType. If excluded,
defaults to modifying the first assay in the SummarizedExperiment for
the given mDataType.
value: A matrix of values to assign to the assay slot of the
SummarizedExperiment for the selected mDataType. The rownames and
column names must match the associated SummarizedExperiment.
featureInfo: Retrieve a DataFrame of feature metadata for the specified
mDataType from the molecularProfiles slot of a ToxicoSet object. More
specifically, retrieve the @rowData slot from the SummarizedExperiment
from the @molecularProfiles of a ToxicoSet object with the name
mDataType.
featureInfo<-: Update the featureInfo(object, mDataType) DataFrame
with new feature metadata. Arguments:
value: A data.frame or DataFrame with updated feature metadata for
the specified molecular profile in the molecularProfiles slot of a
ToxicoSet object.
phenoInfo: Return the @colData slot from the SummarizedExperiment of
mDataType, containing sample-level metadata, from a ToxicoSet object.
phenoInfo<-: Update the @colData slot of the SummarizedExperiment
of mDataType in the @molecularProfiles slot of a ToxicoSet object.
This updates the sample-level metadata in-place.
value: A data.frame or DataFrame object where rows are samples
and columns are sample metadata.
fNames: character() The features names from the rowData slot of a
SummarizedExperiment of mDataType within a ToxicoSet object.
fNames: Updates the rownames of the feature metadata (i.e., rowData)
for a SummarizedExperiment of mDataType within a ToxicoSet object.
value: character() A character vector of new features names for the
rowData of the SummarizedExperiment of mDataType in the
@molecularProfiles slot of a ToxicoSet object. Must be the same
length as nrow(featureInfo(object, mDataType)),
the number of rows in the feature metadata.
mDataNames: character Retrieve the names of the molecular data types
available in the molecularProfiles slot of a ToxicoSet object. These
are the options which can be used in the mDataType parameter of various
molecularProfiles slot accessors methods.
mDataNames: Update the molecular data type names of the
molecularProfiles slot of a ToxicoSet object. Arguments:
value: character vector of molecular datatype names, with length
equal to length(molecularProfilesSlot(object)).
molecularProfilesSlot: Return the contents of the @molecularProfiles
slot of a ToxicoSet object. This will either be a list or
MultiAssayExperiment of SummarizedExperiments.
molecularProfilesSlot<-: Update the contents of the @molecularProfiles
slot of a ToxicoSet object. Arguemnts:
value: A list or MultiAssayExperiment of SummarizedExperiments. The
list and assays should be named for the molecular datatype in each
SummarizedExperiment.
dimension: Optional character(1) One of 'treatment', 'sample' or
'assay' to retrieve rowData, colData or the 'assay_metadata' assay from
the ToxicoSet @sensitvity LongTable object, respectively. Ignored with
warning if @treatmentResponse is not a LongTable object.
...: Additional arguments to the rowData or colData.
LongTable methods. Only used if the sensitivity slot contains a
LongTable object instead of a list and the dimension argument is
specified.
sensitivityInfo: DataFrame or data.frame of sensitivity treatment combo
by sample metadata for the ToxicoSet object. When the dimension
parameter is used, it allows retrieval of the dimension specific metadata
from the LongTable object in @treatmentResponse of a ToxicoSet object.
sensitivityInfo<-: Update the @treatmentResponse slot metadata for a
ToxicoSet object. When used without the dimension argument is behaves
similar to the old ToxicoSet implementation, where the @treatmentResponse slot
contained a list with a $info data.frame item. When the dimension
arugment is used, more complicated assignments can occur where 'sample'
modifies the @sensitvity LongTable colData, 'treatment' the rowData and
'assay' the 'assay_metadata' assay.
Arguments:
value: A data.frame of treatment response experiment metadata,
documenting experiment level metadata (mapping to treatments and samples). If
the @treatmentResponse slot doesn't contain a LongTable and dimension is
not specified, you can only modify existing columns as returned by
sensitivityInfo(object).
sensitivityMeaures: Get the 'sensitivityMeasures' available in a ToxicoSet
object. Each measure reprents some summary of sample sensitivity to a given
treatment, such as ic50, ec50, AUC, AAC, etc. The results are returned as a
character vector with all available metrics for the PSet object.
sensitivityMeaures: Update the sensitivity meaure in a ToxicoSet
object. Thesee values are the column names of the 'profiles' assay and
represent various compued sensitviity metrics such as ic50, ec50, AUC, AAC,
etc.
value: A character vector of new sensitivity measure names, the
then length of the character vector must matcht he number of columns of the
'profiles' assay, excluding metadata and key columns.
sensitivityProfiles: Return the sensitivity profile summaries from the sensitivity slot. This data.frame cotanins vaarious sensitivity summary metrics, such as ic50, amax, EC50, aac, HS, etc as columns, with rows as treatment by sample experiments.
sensitivityProfiles<-: Update the sensitivity profile summaries the
sensitivity slot. Arguments:
-value: A data.frame the the same number of rows as as returned by
sensitivityProfiles(object), but potentially modified columns, such as the
computation of additional summary metrics.
sensitivityRaw: Access the raw sensitiity measurents for a ToxicoSet
object. A 3D array where rows are experiment_ids, columns are doses
and the third dimension is metric, either 'Dose' for the doses used or
'Viability' for the sample viability at that dose.
sensitvityRaw<-: Update the raw dose and viability data in a ToxicoSet.
value: A 3D array object where rows are experiment_ids, columns are
replicates and pages are c('Dose', 'Viability'), with the corresponding
dose or viability measurement for that experiment_id and replicate.
sensNumber: Return a count of viability observations in a ToxicoSet
object for each treatment-combo by sample combination.
sensNumber<-: Update the 'n' item, which holds a matrix with a count
of treatment by sample-line experiment counts, in the list in @treatmentResponse
slot of a ToxicoSet object. Will error when @sensitviity contains
a LongTable object, since the counts are computed on the fly. Arguments:
value: A matrix where rows are samples and columns are treatments, with a
count of the number of experiments for each combination as the values.
pertNumber: array Summary of available perturbation experiments
from in a ToxicoSet object. Returns a 3D array with the number of
perturbation experiments per treatment and sample, and data type.
pertNumber<-: Update the @perturbation$n value in a ToxicoSet object,
which stores a summary of the available perturbation experiments. Arguments:
value: A new 3D array with the number of perturbation experiments per
treatment and sample, and data type
Accessors: See details.
Setters: An updated CoreSet object, returned invisibly.
data(TGGATESsmall) treatmentInfo(TGGATESsmall) treatmentInfo(TGGATESsmall) <- treatmentInfo(TGGATESsmall) treatmentNames(TGGATESsmall) treatmentNames(TGGATESsmall) <- treatmentNames(TGGATESsmall) ## @annotation annotation(TGGATESsmall) annotation(TGGATESsmall) <- annotation(TGGATESsmall) dateCreated(TGGATESsmall) ## dateCreated dateCreated(TGGATESsmall) <- date() name(TGGATESsmall) name(TGGATESsmall) <- 'new_name' sampleInfo(TGGATESsmall) <- sampleInfo(TGGATESsmall) sampleNames(TGGATESsmall) sampleNames(TGGATESsmall) <- sampleNames(TGGATESsmall) ## curation curation(TGGATESsmall) curation(TGGATESsmall) <- curation(TGGATESsmall) datasetType(TGGATESsmall) datasetType(TGGATESsmall) <- 'both' # No assay specified molecularProfiles(TGGATESsmall, 'rna') <- molecularProfiles(TGGATESsmall, 'rna') # Specific assay molecularProfiles(TGGATESsmall, 'rna', 'exprs') <- molecularProfiles(TGGATESsmall, 'rna', 'exprs') # Replace the whole slot molecularProfiles(TGGATESsmall) <- molecularProfiles(TGGATESsmall) featureInfo(TGGATESsmall, 'rna') featureInfo(TGGATESsmall, 'rna') <- featureInfo(TGGATESsmall, 'rna') phenoInfo(TGGATESsmall, 'rna') phenoInfo(TGGATESsmall, 'rna') <- phenoInfo(TGGATESsmall, 'rna') fNames(TGGATESsmall, 'rna') fNames(TGGATESsmall, 'rna') <- fNames(TGGATESsmall, 'rna') mDataNames(TGGATESsmall) mDataNames(TGGATESsmall) <- mDataNames(TGGATESsmall) molecularProfilesSlot(TGGATESsmall) molecularProfilesSlot(TGGATESsmall) <- molecularProfilesSlot(TGGATESsmall) sensitivityInfo(TGGATESsmall) sensitivityInfo(TGGATESsmall) <- sensitivityInfo(TGGATESsmall) sensitivityMeasures(TGGATESsmall) <- sensitivityMeasures(TGGATESsmall) sensitivityMeasures(TGGATESsmall) <- sensitivityMeasures(TGGATESsmall) sensitivityProfiles(TGGATESsmall) sensitivityProfiles(TGGATESsmall) <- sensitivityProfiles(TGGATESsmall) head(sensitivityRaw(TGGATESsmall)) sensitivityRaw(TGGATESsmall) <- sensitivityRaw(TGGATESsmall) treatmentResponse(TGGATESsmall) treatmentResponse(TGGATESsmall) <- treatmentResponse(TGGATESsmall) sensNumber(TGGATESsmall) sensNumber(TGGATESsmall) <- sensNumber(TGGATESsmall) pertNumber(TGGATESsmall) pertNumber(TGGATESsmall) <- pertNumber(TGGATESsmall)data(TGGATESsmall) treatmentInfo(TGGATESsmall) treatmentInfo(TGGATESsmall) <- treatmentInfo(TGGATESsmall) treatmentNames(TGGATESsmall) treatmentNames(TGGATESsmall) <- treatmentNames(TGGATESsmall) ## @annotation annotation(TGGATESsmall) annotation(TGGATESsmall) <- annotation(TGGATESsmall) dateCreated(TGGATESsmall) ## dateCreated dateCreated(TGGATESsmall) <- date() name(TGGATESsmall) name(TGGATESsmall) <- 'new_name' sampleInfo(TGGATESsmall) <- sampleInfo(TGGATESsmall) sampleNames(TGGATESsmall) sampleNames(TGGATESsmall) <- sampleNames(TGGATESsmall) ## curation curation(TGGATESsmall) curation(TGGATESsmall) <- curation(TGGATESsmall) datasetType(TGGATESsmall) datasetType(TGGATESsmall) <- 'both' # No assay specified molecularProfiles(TGGATESsmall, 'rna') <- molecularProfiles(TGGATESsmall, 'rna') # Specific assay molecularProfiles(TGGATESsmall, 'rna', 'exprs') <- molecularProfiles(TGGATESsmall, 'rna', 'exprs') # Replace the whole slot molecularProfiles(TGGATESsmall) <- molecularProfiles(TGGATESsmall) featureInfo(TGGATESsmall, 'rna') featureInfo(TGGATESsmall, 'rna') <- featureInfo(TGGATESsmall, 'rna') phenoInfo(TGGATESsmall, 'rna') phenoInfo(TGGATESsmall, 'rna') <- phenoInfo(TGGATESsmall, 'rna') fNames(TGGATESsmall, 'rna') fNames(TGGATESsmall, 'rna') <- fNames(TGGATESsmall, 'rna') mDataNames(TGGATESsmall) mDataNames(TGGATESsmall) <- mDataNames(TGGATESsmall) molecularProfilesSlot(TGGATESsmall) molecularProfilesSlot(TGGATESsmall) <- molecularProfilesSlot(TGGATESsmall) sensitivityInfo(TGGATESsmall) sensitivityInfo(TGGATESsmall) <- sensitivityInfo(TGGATESsmall) sensitivityMeasures(TGGATESsmall) <- sensitivityMeasures(TGGATESsmall) sensitivityMeasures(TGGATESsmall) <- sensitivityMeasures(TGGATESsmall) sensitivityProfiles(TGGATESsmall) sensitivityProfiles(TGGATESsmall) <- sensitivityProfiles(TGGATESsmall) head(sensitivityRaw(TGGATESsmall)) sensitivityRaw(TGGATESsmall) <- sensitivityRaw(TGGATESsmall) treatmentResponse(TGGATESsmall) treatmentResponse(TGGATESsmall) <- treatmentResponse(TGGATESsmall) sensNumber(TGGATESsmall) sensNumber(TGGATESsmall) <- sensNumber(TGGATESsmall) pertNumber(TGGATESsmall) pertNumber(TGGATESsmall) <- pertNumber(TGGATESsmall)
The ToxicoSet (tSet) class was development to contain and organise large ToxicGenomic datasets as well as provide useful tools for interacting with this data. Functions are included for exploring the relationship between survival fraction and gene expression in cultured human and rat tissues during exposure to a wide ranges of compounds. Features include plotting dose and exposure time curves, calculating AUC, fitting linear models and computing sensitivity signatures.
An object of the ToxicoSet class
annotationA list of annotation data about the ToxicoSet,
including the $name and the session information for how the object
was creating, detailing the exact versions of R and all the packages used
molecularProfilesA list containing SummarizedExperiment
type object for holding data for RNA, DNA, SNP and CNV
measurements, with associated fData and pData
containing the row and column metadata
sampleA data.frame containing the annotations for all the cell
lines profiled in the data set, across all data types
treatmentA data.frame containg the annotations for all the drugs
profiled in the data set, across all data types
treatmentResponseA list containing all the data for the sensitivity
experiments, including $info, a data.frame containing the
experimental info,$raw a 3D array containing raw data,
$profiles, a data.frame containing sensitivity profiles
statistics, and $n, a data.frame detailing the number of
experiments for each cell-drug pair
perturbationA list containting $n, a data.frame
summarizing the available perturbation data,
curationA list containing mappings for $treatment,
sample, tissue names used in the data set to universal
identifiers used between different ToxicoSet objects
datasetTypeA character string of 'sensitivity',
'perturbation', or both detailing what type of data can be found in the
ToxicoSet, for proper processing of the data
Update the ToxicoSet class after changes in it struture or API
## S4 method for signature 'ToxicoSet' updateObject(object)## S4 method for signature 'ToxicoSet' updateObject(object)
object |
A |
ToxicoSet with update class structure.